@@ -16,13 +16,17 @@ class Command(BaseCommand):
         make_option('--app-label',dest='app_label',help='The app label to which the local model belongs.'),
         make_option('--local-model',dest='local_mod',help='The name of the local model'),
         make_option('--local-id',dest='local_id',help='The id of the local model'),
-        make_option('--content-key',dest='content_key',help='The ACE content key to associate.'),
     )
     
     def handle(self,*args,**options):
         """
         Handler method.
         """
+        if not len(args) == 1:
+            raise CommandError('Must specify content key as arg.')
+        
+        content_key = args[0]
+        print 'content key is',content_key
         print 'options are:',options
         content_type = None
         try:
@@ -37,6 +41,6 @@ class Command(BaseCommand):
         AxilentContentRecord.objects.create(local_content_type=content_type,
                                             local_id=options['local_id'],
                                             axilent_content_type=local_mod.ACE.content_type,
-                                            axilent_content_key=options['content_key'])
+                                            axilent_content_key=content_key)
         
         print 'ACE content record created'
